@@ -1,19 +1,19 @@
 /**************************************************************
- *** RHmm version 1.4.3                                     
+ *** RHmm version 1.4.4                                     
  ***                                                         
  *** File: OTMathUtil.h 
  ***                                                         
  *** Author: Ollivier TARAMASCO <Ollivier.Taramasco@imag.fr> 
  *** Author: Sebastian BAUER <sebastian.bauer@charite.de>
- *** Date: 2010/12/01                                     
+ *** Date: 2010/12/09                                     
  ***                                                         
  **************************************************************/
 
-#ifndef _OTMathUtil_H_
-#define _OTMathUtil_H_
+#ifndef _OTMATHUTIL_H_
+#define _OTMATHUTIL_H_
+#pragma once
 
 #include "cOTError.h"
 #include "cOTVector.h"
 #include "cOTMatrix.h"
-
-#endif //_OTMathUtil_H_
+#endif //_OTMATHUTIL_H_
