@@ -1,16 +1,17 @@
 /**************************************************************
- *** RHmm version 1.4.3                                     
+ *** RHmm version 1.4.4                                     
  ***                                                         
  *** File: cHmm.h 
  ***                                                         
  *** Author: Ollivier TARAMASCO <Ollivier.Taramasco@imag.fr> 
  *** Author: Sebastian BAUER <sebastian.bauer@charite.de>
- *** Date: 2010/12/01                                     
+ *** Date: 2010/12/09                                     
  ***                                                         
  **************************************************************/
 
 #ifndef _CHMM_H_
 #define _CHMM_H_
+#pragma once
 
 #include "Hmm.h"
 #include "cInParam.h"
@@ -34,7 +35,4 @@ class cHmm
                 void SetParam(cOTVector& theParam) ;
                 void GetParam(cOTVector& theParam) ;            
 } ;
-
-
-
-#endif _CHMM_H_//
+#endif //_CHMM_H_
