@@ -1,11 +1,11 @@
 /**************************************************************
- *** RHmm version 1.4.3                                     
+ *** RHmm version 1.4.4                                     
  ***                                                         
  *** File: cOTError.cpp 
  ***                                                         
  *** Author: Ollivier TARAMASCO <Ollivier.Taramasco@imag.fr> 
  *** Author: Sebastian BAUER <sebastian.bauer@charite.de>
- *** Date: 2010/12/01                                     
+ *** Date: 2010/12/09                                     
  ***                                                         
  **************************************************************/
 
@@ -15,6 +15,6 @@ cOTError::cOTError(const char *theMess)
 {
         if (theMess != (char *)NULL) 
                 std::cout << theMess << std::endl ;
-        exit(0) ;
+        std::exit(0) ;
 }
 
