@@ -1,16 +1,17 @@
 /**************************************************************
- *** RHmm version 1.4.3                                     
+ *** RHmm version 1.4.4                                     
  ***                                                         
  *** File: cOTError.h 
  ***                                                         
  *** Author: Ollivier TARAMASCO <Ollivier.Taramasco@imag.fr> 
  *** Author: Sebastian BAUER <sebastian.bauer@charite.de>
- *** Date: 2010/12/01                                     
+ *** Date: 2010/12/09                                     
  ***                                                         
  **************************************************************/
 
 #ifndef _COTERROR_H_
-#define _COTERROR_H_
+#define _COTERROR_H
+#pragma once
 #include <cstdlib>
 #include <iostream>
 
@@ -28,4 +29,4 @@ class cOTError
                 cOTError(const char *theMess) ;
 } ;
 
-#endif //_COTERROR_H_
+#endif // #_COTERROR_H
